package de.intevation.flys.artifacts.model;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.artifactdatabase.state.DefaultFacet;

import de.intevation.flys.artifacts.StaticWQKmsArtifact;
import de.intevation.flys.artifacts.model.FacetTypes;

/**
 * Facet to show W|Q|km Values.
 */
public class WQKmsFacet
extends      DefaultFacet
implements   FacetTypes {

    /** Trivial Constructor. */
    public WQKmsFacet(String description) {
        this(STATIC_WQKMS, description);
    }

    public WQKmsFacet(String name, String description) {
        this.name        = name;
        this.description = description;
        this.index       = 0;
    }


    /**
     * Returns the data this facet requires.
     *
     * @param artifact the owner artifact.
     * @param context  the CallContext (ignored).
     *
     * @return the data.
     */
    @Override
    public Object getData(Artifact artifact, CallContext context) {
        StaticWQKmsArtifact staticData =
            (StaticWQKmsArtifact) artifact;
        return staticData.getWQKms(0);
    }


    /**
     * Create a deep copy of this Facet.
     * @return a deep copy.
     */
    @Override
    public WQKmsFacet deepCopy() {
        WQKmsFacet copy = new WQKmsFacet(description);
        copy.set(this);
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
